pub enum EmailError {
InvalidAddress(String),
MissingField(String),
BackendError(String),
SmtpError(String),
IoError(Error),
TemplateError(String),
AttachmentError(String),
InvalidHeader(String),
HeaderInjection(String),
}Variants
InvalidAddress(String)
MissingField(String)
BackendError(String)
SmtpError(String)
IoError(Error)
TemplateError(String)
AttachmentError(String)
InvalidHeader(String)
HeaderInjection(String)
Implementations
Sourceimpl EmailError
impl EmailError
Sourcepub fn is_transient(&self) -> bool
pub fn is_transient(&self) -> bool
Returns true if this is a transient error that can be safely suppressed by fail_silently mode.
Configuration errors, authentication failures, and security errors are never considered transient and will always propagate even when fail_silently is enabled.