pub struct EmailMessage { /* private fields */ }Expand description
Represents an email message with validated addresses.
All fields are private to enforce validation through the builder. Use getter methods for read access and the builder for construction. Direct field assignment is not possible, preventing bypass of validation.
Implementations
Sourceimpl EmailMessage
impl EmailMessage
Sourcepub fn builder() -> EmailMessageBuilder
pub fn builder() -> EmailMessageBuilder
Create a new builder for constructing an EmailMessage.
Sourcepub fn from_email(&self) -> &str
pub fn from_email(&self) -> &str
Get the from email address.
Sourcepub fn alternatives(&self) -> &[Alternative]
pub fn alternatives(&self) -> &[Alternative]
Get the alternatives.
Sourcepub fn attachments(&self) -> &[Attachment]
pub fn attachments(&self) -> &[Attachment]
Get the attachments.
Sourcepub async fn send(&self, backend: &dyn EmailBackend) -> EmailResult<()>
pub async fn send(&self, backend: &dyn EmailBackend) -> EmailResult<()>
Send the email using the given backend.
Sourcepub async fn send_with_backend(
&self,
backend: &dyn EmailBackend,
) -> EmailResult<()>
pub async fn send_with_backend( &self, backend: &dyn EmailBackend, ) -> EmailResult<()>
Send the email using the given backend (alias for send).